@@ -95,7 +95,8 @@
                                   kVLCPlayerIsShuffleEnabled: kVLCPlayerIsShuffleEnabledDefaultValue,
                                   kVLCPlayerIsRepeatEnabled: kVLCPlayerIsRepeatEnabledDefaultValue,
                                   kVLCSettingPlaybackSpeedDefaultValue: @(1.0),
-                                  kVLCPlayerShowPlaybackSpeedShortcut: @(NO)
+                                  kVLCPlayerShowPlaybackSpeedShortcut: @(NO),
+                                  kVLCSettingAlwaysPlayURLs: @(NO)
     };
     [defaults registerDefaults:appDefaults];
 }
@@ -153,6 +154,9 @@
 
     [self configureShortCutItemsWithApplication:application];
 
+    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
+    [defaults setInteger:([defaults integerForKey:kVLCNumberOfLaunches] + 1) forKey:kVLCNumberOfLaunches];
+
     return YES;
 }
 
@@ -244,6 +248,9 @@
         VLCAppCoordinator *appCoordinator = [VLCAppCoordinator sharedInstance];
         [appCoordinator.mediaLibraryService savePlaybackStateFrom:vps];
     }
+
+    VLCFavoriteService *fs = [[VLCAppCoordinator sharedInstance] favoriteService];
+    [fs storeContentSynchronously];
 }
 
 - (void)application:(UIApplication *)application performActionForShortcutItem:(UIApplicationShortcutItem *)shortcutItem completionHandler:(void (^)(BOOL))completionHandler
