@@ -33,7 +33,9 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
     private var mediaLibraryService: MediaLibraryService
 
     var searchBar = UISearchBar(frame: .zero)
-    var isSearching: Bool = false
+    private var currentDataSet: [VLCMLObject] {
+        return searchDataSource.isSearching ? searchDataSource.searchData : model.anyfiles
+    }
     private let mediaGridCellNibIdentifier = "MediaGridCollectionCell"
     private var searchBarConstraint: NSLayoutConstraint?
     private var searchDataSource: LibrarySearchDataSource
@@ -43,7 +45,8 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
     private lazy var editController: EditController = {
         let editController = EditController(mediaLibraryService:mediaLibraryService,
                                             model: model,
-                                            presentingView: collectionView)
+                                            presentingView: collectionView,
+                                            searchDataSource: searchDataSource)
         editController.delegate = self
         return editController
     }()
@@ -130,6 +133,10 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
     private lazy var editBarButton: UIBarButtonItem = {
         return setupEditBarButton()
     }()
+    
+    private lazy var clearHistoryButton: UIBarButtonItem = {
+        return setupClearHistoryButton()
+    }()
 
     private lazy var selectAllBarButton: UIBarButtonItem = {
         return setupSelectAllButton()
@@ -148,6 +155,11 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
         if model is PlaylistModel {
             emptyView.contentType = .noPlaylists
         }
+        
+        // Check if history page
+        if model is HistoryModel {
+            emptyView.contentType = .noHistory
+        }
 
         // Check if it is inside a playlist
         if let collectionModel = model as? CollectionModel,
@@ -201,6 +213,10 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
         } else if let collection = model as? CollectionModel {
             navItemTitle.text = collection.mediaCollection.title()
         }
+        
+        if model is HistoryModel {
+            navItemTitle.text = NSLocalizedString("BUTTON_HISTORY", comment: "")
+        }
 
         navItemTitle.textColor = PresentationTheme.current.colors.navigationbarTextColor
         navItemTitle.font = UIFont.preferredCustomFont(forTextStyle: .headline).bolded
@@ -233,7 +249,7 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
         model = secondModel
         secondModel = previousModel
         self.searchDataSource = LibrarySearchDataSource(model: model)
-        editController = EditController(mediaLibraryService: mediaLibraryService, model: model, presentingView: collectionView)
+        editController = EditController(mediaLibraryService: mediaLibraryService, model: model, presentingView: collectionView, searchDataSource: searchDataSource)
         editController.delegate = self
         model.sort(by: secondModel.sortModel.currentSort, desc: secondModel.sortModel.desc)
         setupCollectionView()
@@ -337,7 +353,7 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
         }
 
         /* this function can be called multiple times from different threads in short
-         * intervalls, but we may not reload the views without the previous to finish */
+         * intervals, but we may not reload the views without the previous to finish */
         reloadLock.lock()
 
         guard Thread.isMainThread else {
@@ -360,7 +376,7 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
         collectionView?.reloadData()
         updateUIForContent()
 
-        if !isSearching {
+        if !searchDataSource.isSearching {
             popViewIfNecessary()
         }
 
@@ -372,7 +388,7 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
     }
 
     func isEmptyCollectionView() -> Bool {
-        return collectionView?.numberOfItems(inSection: 0) == 0
+        return currentDataSet.isEmpty
     }
 
     @available(*, unavailable)
@@ -423,12 +439,12 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
         cachedCellSize = .zero
         collectionView.collectionViewLayout.invalidateLayout()
         setupCollectionView() //Fixes crash that is caused due to layout change
-        showGuideOnLaunch()
         setNavbarAppearance()
         loadSort()
     }
 
     override func viewDidAppear(_ animated: Bool) {
+        showGuideOnLaunch()
         updateCollectionViewForAlbum()
     }
 
@@ -467,6 +483,25 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
             navigationController.modalPresentationStyle = .formSheet
             self.present(navigationController, animated: true)
             userDefaults.set(true, forKey: kVLCHasLaunchedBefore)
+        } else {
+            var lastNagMonth = userDefaults.integer(forKey: kVLCHasNaggedThisMonth)
+            let numberOfLaunches = userDefaults.integer(forKey: kVLCNumberOfLaunches)
+            let currentMonth = NSCalendar.current.component(.month, from: Date())
+
+            if lastNagMonth == 12 && currentMonth < 12 {
+                lastNagMonth = 0
+            }
+
+            if lastNagMonth < currentMonth && numberOfLaunches >= 5 {
+                userDefaults.setValue(currentMonth, forKey: kVLCHasNaggedThisMonth)
+                userDefaults.setValue(0, forKey: kVLCNumberOfLaunches)
+                let donationVC = VLCDonationNagScreenViewController(nibName: "VLCDonationNagScreenViewController", bundle: nil)
+                let donationNC = UINavigationController(rootViewController: donationVC)
+                donationNC.navigationBar.isHidden = true
+                donationNC.modalTransitionStyle = .crossDissolve
+                donationNC.modalPresentationStyle = .overFullScreen
+                self.present(donationNC, animated: true)
+            }
         }
     }
 
@@ -484,10 +519,10 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
     override func scrollViewWillBeginDragging(_ scrollView: UIScrollView) {
         resetScrollView()
     }
-
+    
     override func scrollViewDidScroll(_ scrollView: UIScrollView) {
         // This ensures that the search bar is always visible like a sticky while searching
-        if isSearching {
+        if searchDataSource.isSearching {
             searchBar.endEditing(true)
             delegate?.enableCategorySwitching(for: self, enable: true)
             // End search if scrolled and the textfield is empty
@@ -521,8 +556,6 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
 
         editController.shouldResetCells(!isEditing)
 
-        // might have an issue if the old datasource was search
-        // Most of the edit logic is handled inside editController
         collectionView?.dataSource = editing ? editController : self
         collectionView?.delegate = editing ? editController : self
         if #available(iOS 14.0, *) {
@@ -539,7 +572,6 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
         PlaybackService.sharedInstance().setPlayerHidden(editing)
 
         searchBar.resignFirstResponder()
-        searchBarConstraint?.constant = -self.searchBarSize
 
         // When quitting the edit mode, reset all selection state
         if isEditing == false {
@@ -554,10 +586,6 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
         if isEditing {
             tabBarController?.editToolBar()?.delegate = editController
             tabBarController?.displayEditToolbar(with: model)
-            UIView.animate(withDuration: 0) {
-                [weak self] in
-                self?.collectionView.contentInset = .zero
-            }
         } else {
             tabBarController?.hideEditToolbar()
         }
@@ -586,7 +614,7 @@ private extension MediaCategoryViewController {
     }
 
     private func updateUIForContent() {
-        if isSearching {
+        if searchDataSource.isSearching {
             return
         }
 
@@ -594,7 +622,7 @@ private extension MediaCategoryViewController {
         if isEmpty {
             collectionView?.setContentOffset(.zero, animated: false)
         }
-        searchBar.isHidden = isEmpty || isEditing
+        searchBar.isHidden = isEmpty
         collectionView?.backgroundView = isEmpty ? emptyView : nil
         updateBarButtonItems()
     }
@@ -648,6 +676,14 @@ extension MediaCategoryViewController {
         selectAll.accessibilityHint = NSLocalizedString("BUTTON_SELECT_ALL_HINT", comment: "")
         return selectAll
     }
+    
+    private func setupClearHistoryButton() -> UIBarButtonItem {
+        let clearHistory = UIBarButtonItem(title: NSLocalizedString("BUTTON_CLEAR", comment: ""),
+                                        style: .plain, target: self,
+                                           action: #selector(handleClearHistory))
+        clearHistory.accessibilityLabel = NSLocalizedString("BUTTON_CLEAR", comment: "")
+        return clearHistory
+    }
 
 
     private func setupSortButton() -> UIButton {
@@ -755,6 +791,22 @@ extension MediaCategoryViewController {
         }
     }
 
+    @objc func handleClearHistory() {
+        let cancelAction: UIAlertAction = UIAlertAction(title: NSLocalizedString("BUTTON_CANCEL", comment: ""), style: .cancel)
+
+        let clearAction: UIAlertAction = UIAlertAction(title: NSLocalizedString("BUTTON_CLEAR", comment: ""), style: .destructive) { _ in
+            self.mediaLibraryService.medialib.clearHistory()
+        }
+
+        let alertController: UIAlertController = UIAlertController(title: NSLocalizedString("CLEAR_HISTORY_TITLE", comment: ""),
+                                                                   message: NSLocalizedString("CLEAR_HISTORY_MESSAGE", comment: ""),
+                                                                   preferredStyle: .alert)
+        alertController.addAction(cancelAction)
+        alertController.addAction(clearAction)
+
+        present(alertController, animated: true)
+    }
+
     @objc func handleSelectAll() {
         isAllSelected = !isAllSelected
         editController.selectAll()
@@ -788,6 +840,10 @@ extension MediaCategoryViewController: VLCRendererDiscovererManagerDelegate {
             navigationItem.rightBarButtonItems = rightBarButtonItems()
             navigationItem.setHidesBackButton(isEditing, animated: true)
         }
+        
+        if self is HistoryCategoryViewController {
+            navigationItem.rightBarButtonItem = clearHistoryButton
+        }
 
         if isEmptyCollectionView() {
             navigationItem.rightBarButtonItem = nil
@@ -818,7 +874,7 @@ extension MediaCategoryViewController: VLCRendererDiscovererManagerDelegate {
 extension MediaCategoryViewController {
     func searchBarTextDidBeginEditing(_ searchBar: UISearchBar) {
         reloadData()
-        isSearching = true
+        searchDataSource.isSearching = true
         delegate?.enableCategorySwitching(for: self, enable: false)
         searchBar.setShowsCancelButton(true, animated: true)
     }
@@ -829,7 +885,7 @@ extension MediaCategoryViewController {
         searchBar.text = ""
         searchDataSource.shouldReloadFor(searchString: "")
         searchBar.setShowsCancelButton(false, animated: true)
-        isSearching = false
+        searchDataSource.isSearching = false
         delegate?.enableCategorySwitching(for: self, enable: true)
         reloadData()
     }
@@ -863,7 +919,7 @@ private extension MediaCategoryViewController {
                 case .appendToQueue:
                     playbackController.appendMediaToQueue(media)
                 case .playAsAudio:
-                    playbackController.setPlayAsAudio(true)
+                    playbackController.playAsAudio = true
                     playbackController.play(media)
                 default:
                     assertionFailure("generatePlayAction: cannot be used with other actions")
@@ -886,7 +942,7 @@ private extension MediaCategoryViewController {
                 case .appendToQueue:
                     playbackController.appendCollectionToQueue(files)
                 case .playAsAudio:
-                    playbackController.setPlayAsAudio(true)
+                    playbackController.playAsAudio = true
                     playbackController.playCollection(files)
                 default:
                     assertionFailure("generatePlayAction: cannot be used with other actions")
@@ -897,9 +953,8 @@ private extension MediaCategoryViewController {
 
     @available(iOS 13.0, *)
     private func generateUIMenuForContent(at indexPath: IndexPath) -> UIMenu {
-        let modelContentArray = isSearching ? searchDataSource.searchData : model.anyfiles
         let index = indexPath.row
-        let modelContent = modelContentArray.objectAtIndex(index: index)
+        let modelContent = currentDataSet.objectAtIndex(index: index)
 
         // Remove addToMediaGroup from quick actions since it is applicable only to multiple media
         let actionList = EditButtonsFactory.buttonList(for: model).filter({
@@ -945,7 +1000,12 @@ private extension MediaCategoryViewController {
                     [weak self] _ in
                     if let modelContent = modelContent {
                         self?.editController.editActions.objects = [modelContent]
-                        self?.editController.editActions.delete()
+                        self?.editController.editActions.delete() {
+                            [weak self] state in
+                            if state == .success {
+                                self?.searchDataSource.deleteInSearch(index: index)
+                            }
+                        }
                     }
                 })
             case .share:
@@ -999,12 +1059,11 @@ extension MediaCategoryViewController {
     
     
     private func selectedItem(at indexPath: IndexPath) {
-        let mediaObjectArray = isSearching ? searchDataSource.searchData : model.anyfiles
-        let modelContent = mediaObjectArray.objectAtIndex(index: indexPath.row)
+        let modelContent = currentDataSet.objectAtIndex(index: indexPath.row)
 
         // Reset the play as audio variable
         let playbackService = PlaybackService.sharedInstance()
-        playbackService.setPlayAsAudio(false)
+        playbackService.playAsAudio = false
 
         if let mediaGroup = modelContent as? VLCMLMediaGroup,
             mediaGroup.nbTotalMedia() == 1 && !mediaGroup.userInteracted() {
@@ -1043,7 +1102,7 @@ extension MediaCategoryViewController {
     override func collectionView(_ collectionView: UICollectionView,
                                  contextMenuConfigurationForItemAt indexPath: IndexPath,
                                  point: CGPoint) -> UIContextMenuConfiguration? {
-        let modelContent = self.isSearching ? self.searchDataSource.searchData.objectAtIndex(index: indexPath.row) : self.model.anyfiles[indexPath.row]
+        let modelContent = currentDataSet.objectAtIndex(index: indexPath.row)
         let cell = collectionView.cellForItem(at: indexPath)
         var thumbnail: UIImage? = nil
         if let cell = cell as? MovieCollectionViewCell {
@@ -1096,7 +1155,7 @@ extension MediaCategoryViewController {
 
 extension MediaCategoryViewController {
     override func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
-        return isSearching ? searchDataSource.searchData.count : model.anyfiles.count
+        return currentDataSet.count
     }
 
     override func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
@@ -1105,8 +1164,7 @@ extension MediaCategoryViewController {
             return UICollectionViewCell()
         }
 
-        let mediaObjectArray = isSearching ? searchDataSource.searchData : model.anyfiles
-        let mediaObject = mediaObjectArray.objectAtIndex(index: indexPath.row)
+        let mediaObject = currentDataSet.objectAtIndex(index: indexPath.row)
 
         guard mediaObject != nil else {
             assertionFailure("MediaCategoryViewController: Failed to fetch media object.")
@@ -1327,20 +1385,28 @@ extension MediaCategoryViewController: EditControllerDelegate {
     }
 
     func editControllerDidSelectMultipleItem(editContrller: EditController) {
+        searchBar.isUserInteractionEnabled = false
+        searchBar.alpha = 0.5
         if let editToolbar = tabBarController?.editToolBar() {
             editToolbar.enableEditActions(true)
         }
     }
 
-    func editControllerDidDeSelectMultipleItem(editContrller: EditController) {
+    func editControllerDidDeSelectMultipleItem() {
+        searchBar.isUserInteractionEnabled = true
+        searchBar.alpha = 1
         if let editToolbar = tabBarController?.editToolBar() {
             editToolbar.enableEditActions(false)
         }
     }
 
     func editControllerDidFinishEditing(editController: EditController?) {
-        // NavigationItems for Collections are create from the parent, there is no need to propagate the information.
-        if self is CollectionCategoryViewController {
+        if let model = model as? CollectionModel,
+           model.mediaCollection is VLCMLMediaGroup {
+            // The media group's view can be discarded when the group is emptied, there is a need to propagate the information.
+            delegate?.setEditingStateChanged(for: self, editing: false)
+        } else if self is CollectionCategoryViewController {
+            // NavigationItems for other Collections are created from the parent, there is no need to propagate the information.
             handleEditingInsideCollection()
         } else {
             delegate?.setEditingStateChanged(for: self, editing: false)
@@ -1501,14 +1567,13 @@ extension MediaCategoryViewController: MediaLibraryBaseModelObserver {
 extension MediaCategoryViewController {
     func play(media: VLCMLMedia, at indexPath: IndexPath) {
         let playbackController = PlaybackService.sharedInstance()
-        var autoPlayNextItem = UserDefaults.standard.bool(forKey: kVLCAutomaticallyPlayNextItem)
+        var autoPlayNextItem: Bool = userDefaults.bool(forKey: kVLCAutomaticallyPlayNextItem)
 
         playbackController.fullscreenSessionRequested = media.type() != .audio
 
         if let model = model as? CollectionModel,
-           model.mediaCollection is VLCMLPlaylist,
-           !autoPlayNextItem {
-            autoPlayNextItem = true
+           model.mediaCollection is VLCMLPlaylist {
+            autoPlayNextItem = userDefaults.bool(forKey: kVLCPlaylistPlayNextItem)
         }
 
         if !autoPlayNextItem {
@@ -1522,10 +1587,19 @@ extension MediaCategoryViewController {
         if let mediaGroupModel = model as? MediaGroupViewModel {
             mediaGroupModel.fileArrayQueue.sync {
                 var singleGroup = [VLCMLMediaGroup]()
+
+                if searchDataSource.isSearching,
+                   let dataSet = currentDataSet as? [VLCMLMediaGroup] {
+                    singleGroup = dataSet
+                } else {
+                    singleGroup = mediaGroupModel.files
+                }
+
                 // Filter single groups
-                singleGroup = mediaGroupModel.files.filter() {
+                singleGroup = singleGroup.filter() {
                     return $0.nbTotalMedia() == 1 && !$0.userInteracted()
                 }
+
                 singleGroup.forEach() {
                     guard let media = $0.media(of: .unknown)?.first else {
                         assertionFailure("MediaCategoryViewController: play: Failed to fetch media.")
@@ -1538,7 +1612,7 @@ extension MediaCategoryViewController {
         } else if let model = model as? MediaCollectionModel {
             tracks = model.files() ?? []
         } else {
-            tracks = (isSearching ? searchDataSource.searchData : model.anyfiles) as? [VLCMLMedia] ?? []
+            tracks = currentDataSet as? [VLCMLMedia] ?? []
         }
         playbackController.playMedia(at: index, fromCollection: tracks)
     }
@@ -1552,11 +1626,14 @@ extension MediaCategoryViewController: MediaCollectionViewCellDelegate {
         guard let indexPath = collectionView.indexPath(for: cell) else {
             return
         }
-
-        let modelContentArray = isSearching ? searchDataSource.searchData : model.anyfiles
-        let modelContent = modelContentArray.objectAtIndex(index: indexPath.row)
+        let modelContent = currentDataSet.objectAtIndex(index: indexPath.row)
         editController.editActions.objects = [modelContent!]
-        editController.editActions.delete()
+        editController.editActions.delete() {
+            [weak self] state in
+            if state == .success {
+                self?.searchDataSource.deleteInSearch(index: indexPath.row)
+            }
+        }
     }
 
     func mediaCollectionViewCellMediaTapped(in cell: MediaCollectionViewCell) {
@@ -1565,6 +1642,7 @@ extension MediaCategoryViewController: MediaCollectionViewCellDelegate {
         }
 
         selectedItem(at: indexPath)
+        collectionView.reloadData()
     }
 
     func mediaCollectionViewCellSetScrolledCellIndex(of cell: MediaCollectionViewCell?) {
