@@ -34,7 +34,7 @@
 
 @interface VLCServerListTVViewController ()
 @property (nonatomic, copy) NSMutableArray<id<VLCLocalNetworkService>> *networkServices;
-
+@property (nonatomic, strong) UIButton *favoritesButton;
 @end
 
 @implementation VLCServerListTVViewController
@@ -66,6 +66,17 @@
     [nothingFoundView setTranslatesAutoresizingMaskIntoConstraints:NO];
     [self.view addSubview:nothingFoundView];
 
+    // Create and configure the "View Favorites" button
+    self.favoritesButton = [UIButton buttonWithType:UIButtonTypeSystem];
+    [self.favoritesButton setImage:[UIImage imageNamed:@"heart.fill"] forState: UIControlStateNormal];
+    [self.favoritesButton addTarget:self action:@selector(viewFavoritesButtonTapped:) forControlEvents:UIControlEventPrimaryActionTriggered];
+    [self.favoritesButton sizeToFit];
+
+        // Add the button to the navigation bar
+    UIBarButtonItem *favoritesBarButtonItem = [[UIBarButtonItem alloc] initWithCustomView:self.favoritesButton];
+    self.navigationItem.rightBarButtonItem = favoritesBarButtonItem;
+    self.navigationController.navigationBarHidden = NO;
+
     NSLayoutConstraint *yConstraint = [NSLayoutConstraint constraintWithItem:nothingFoundView
                                                                    attribute:NSLayoutAttributeCenterY
                                                                    relatedBy:NSLayoutRelationEqual
@@ -101,18 +112,17 @@
     return NSLocalizedString(@"LOCAL_NETWORK", nil);
 }
 
-- (void)viewDidAppear:(BOOL)animated
+- (void)viewWillAppear:(BOOL)animated
 {
-    [super viewDidAppear:animated];
+    [super viewWillAppear:animated];
     [self.discoveryController startDiscovery];
 }
 
-- (void)viewDidDisappear:(BOOL)animated
+- (void)viewWillDisappear:(BOOL)animated
 {
-    [super viewDidDisappear:animated];
+    [super viewWillDisappear:animated];
     [self.discoveryController stopDiscovery];
     self.networkServices = nil;
-    [self.collectionView reloadData];
 }
 
 #pragma mark - Collection view data source
@@ -196,7 +206,7 @@
             if (login.protocolIdentifier)
                 [self showLoginAlertWithLogin:login];
             else {
-                VLCNetworkLoginTVViewController *targetViewController = [VLCNetworkLoginTVViewController alloc];
+                VLCNetworkLoginTVViewController *targetViewController = [[VLCNetworkLoginTVViewController alloc] initWithNibName:nil bundle:nil];
                 [self presentViewController:targetViewController animated:YES completion:nil];
             }
         } else {
@@ -403,5 +413,13 @@
     self.networkServices = newNetworkServices;
     [self.collectionView reloadData];
 }
+#pragma mark - Trigger VC for Favorite Folders
+- (void)viewFavoritesButtonTapped:(UIButton *)sender
+{
+    VLCFavoriteListViewController *favoriteListViewController = [[VLCFavoriteListViewController alloc] init];
+     UINavigationController *navController = [[UINavigationController alloc] initWithRootViewController:favoriteListViewController];
+    navController.view.window.translatesAutoresizingMaskIntoConstraints = NO;
+     [self presentViewController: navController animated:YES completion:nil];
+}
 
 @end
