@@ -33,7 +33,7 @@ typedef NS_ENUM(NSInteger, VLCPlayerScanState)
 
 @property (nonatomic) CADisplayLink *displayLink;
 @property (nonatomic) NSTimer *audioDescriptionScrollTimer;
-@property (nonatomic) NSTimer *hidePlaybackControlsViewAfterDeleayTimer;
+@property (nonatomic) NSTimer *hidePlaybackControlsViewAfterDelayTimer;
 @property (nonatomic) VLCPlaybackInfoTVViewController *infoViewController;
 @property (nonatomic) NSNumber *scanSavedPlaybackRate;
 @property (nonatomic) VLCPlayerScanState scanState;
@@ -838,7 +838,7 @@ static const NSInteger VLCJumpInterval = 10000; // 10 seconds
 }
 - (void)hidePlaybackControlsIfNeededAfterDelay
 {
-    self.hidePlaybackControlsViewAfterDeleayTimer = [NSTimer scheduledTimerWithTimeInterval:3.0
+    self.hidePlaybackControlsViewAfterDelayTimer = [NSTimer scheduledTimerWithTimeInterval:.75
                                                                                      target:self
                                                                                    selector:@selector(fireHidePlaybackControlsIfNotPlayingTimer:)
                                                                                    userInfo:nil repeats:NO];
@@ -858,9 +858,9 @@ static const NSInteger VLCJumpInterval = 10000; // 10 seconds
 
 
 #pragma mark - Properties
-- (void)setHidePlaybackControlsViewAfterDeleayTimer:(NSTimer *)hidePlaybackControlsViewAfterDeleayTimer {
-    [_hidePlaybackControlsViewAfterDeleayTimer invalidate];
-    _hidePlaybackControlsViewAfterDeleayTimer = hidePlaybackControlsViewAfterDeleayTimer;
+- (void)setHidePlaybackControlsViewAfterDelayTimer:(NSTimer *)hidePlaybackControlsViewAfterDelayTimer {
+    [_hidePlaybackControlsViewAfterDelayTimer invalidate];
+    _hidePlaybackControlsViewAfterDelayTimer = hidePlaybackControlsViewAfterDelayTimer;
 }
 
 - (VLCPlaybackInfoTVViewController *)infoViewController
@@ -931,21 +931,18 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
                 self.audioAlbumNameLabel.text = albumName;
                 self.audioAlbumNameLabel.hidden = NO;
             }];
-            APLog(@"Audio-only track meta changed, tracing artist '%@' and album '%@'", artist, albumName);
         } else if (artist != nil) {
             [UIView animateWithDuration:.3 animations:^{
                 self.audioArtistLabel.text = artist;
                 self.audioArtistLabel.hidden = NO;
                 self.audioAlbumNameLabel.hidden = YES;
             }];
-            APLog(@"Audio-only track meta changed, tracing artist '%@'", artist);
         } else if (title != nil) {
             NSRange deviderRange = [title rangeOfString:@" - "];
             if (deviderRange.length != 0) { // for radio stations, all we have is "ARTIST - TITLE"
                 artist = [title substringToIndex:deviderRange.location];
                 title = [title substringFromIndex:deviderRange.location + deviderRange.length];
             }
-            APLog(@"Audio-only track meta changed, tracing artist '%@'", artist);
             [UIView animateWithDuration:.3 animations:^{
                 self.audioArtistLabel.text = artist;
                 self.audioArtistLabel.hidden = NO;
